# Run simulation 
Res0.0 <- PBR.sim(r=0.04, tau=0.02, CV=0.2, FR=0.0, Int=4)
Res0.5 <- PBR.sim(r=0.04, tau=0.02, CV=0.2, FR=0.5, Int=4)
Res1.0 <- PBR.sim(r=0.04, tau=0.02, CV=0.2, FR=1.0, Int=4)

# Function for plotting
Year <- 0:100
Spaghetti1 <- function(SimRes, lty=1, col="black", ns=5, Nsim=1000, Tm=100, main=main){
  plot(0,0,xlim=c(0,Tm),ylim=c(0,1.2),xaxs="i",yaxs="i", 
                 xlab="Year", ylab="Depeletion (N/K)", main=main)
  #confidence intervals
  polygon(c(Year,rev(Year)), c(SimRes$D.05,rev(SimRes$D.95)), col="lightgray")
  polygon(c(Year,rev(Year)), c(SimRes$D.10,rev(SimRes$D.90)), col="gray")
  #some trajectories
  use <- sample(1:Nsim, ns)
  for(j in 1:ns) points(Year, SimRes$D[use[j],], type="l", lty=lty, col=col)
  #median
  points(Year, SimRes$D.med, type="l", lty=lty, col=col, lwd=2)
  #threshold
  rect(0,max(Year), ybottom=0,  ytop=0.5, lwd=0, col=rgb(1, 0, 0, alpha=0.2))
  rect(0,max(Year), ybottom=0.5,ytop=0.7, lwd=0, col=rgb(1, 1, 0, alpha=0.2))
  rect(0,max(Year), ybottom=0.7,ytop=1.2, lwd=0, col=rgb(0, 1, 0, alpha=0.2))
  abline(1,0,lty=2)
}

# Another function for plotting
Spaghetti2 <- function(SimRes, lty=1, col=1, ns=1000, Nsim=1000, Tm=100, main=main){
  points(Year, SimRes$D.med, type="l", lty=lty, col=col, lwd=2)
  use <- sample(1:Nsim, ns)
  for(j in 1:ns) points(Year, SimRes$D[use[j],], type="l", lty=lty, col=col)
  rect(0,max(Year), ybottom=0,  ytop=0.5, lwd=0, col=rgb(1, 0, 0, alpha=0.05))
  rect(0,max(Year), ybottom=0.5,ytop=0.7, lwd=0, col=rgb(1, 1, 0, alpha=0.05))
  rect(0,max(Year), ybottom=0.7,ytop=1.2, lwd=0, col=rgb(0, 1, 0, alpha=0.05))
  abline(1,0,lty=2)
}

# Plot resutls of Spaghetti1
par(mfrow=c(2,2), mar=c(4,4,3,3))
COL <- c("darkgreen", "blue", "red") 
LEGEND <- c("FR=0","FR=0.5", "FR=1.0")
Spaghetti1(Res0.0, lty=1, col=COL[1], main=LEGEND[1])
Spaghetti1(Res0.5, lty=1, col=COL[2], main=LEGEND[2])
Spaghetti1(Res1.0, lty=1, col=COL[3], main=LEGEND[3])

# Plot resutls of Spaghetti2
plot(0,0, xlim=c(0,100), ylim=c(0,1.2), xaxs="i", yaxs="i", 
     xlab="Year", ylab="Depeletion (N/K)")
Spaghetti2(Res0.0, lty=1, col=COL[1], ns=5)
Spaghetti2(Res0.5, lty=1, col=COL[2], ns=5)
Spaghetti2(Res1.0, lty=1, col=COL[3], ns=5)
legend(50, 0.4, lty=rep(1,3), legend=LEGEND, col=COL, bty="n")

