# Re-define PBR.sim for different FR values
PBR.sim.FR <- function(FR, r=0.04, tau=0, CV=0.2, Int=4) 
  PBR.sim(FR=FR, r=r, tau=tau, CV=CV, Int=Int)

# Function for plotting
Box.FinalD <- function(SimRes, Nsim=1000, Tm=100, List=List, main=main){
  Nlist <- length(List) 
  FinalD <- array(NA, c(Nlist, Nsim))
  for(i in 1:Nlist) FinalD[i,] <- SimRes[[i]]$D[,Tm+1]
  boxplot(FinalD~List, ylim=c(0,1.2), yaxs="i", xlab="FR", 
          ylab="Depeletion (N/K)", main=main)
  rect(0,100, ybottom=0,  ytop=0.5, lwd=0, col=rgb(1, 0, 0, alpha=0.1))
  rect(0,100, ybottom=0.5,ytop=0.7, lwd=0, col=rgb(1, 1, 0, alpha=0.1))
  rect(0,100, ybottom=0.7,ytop=1.2, lwd=0, col=rgb(0, 1, 0, alpha=0.1))
  abline(1,0,lty=2)
}

# Run simulation and plot results 
FR <- seq(0,1,0.1)
Res.FR.tau0.CV02 <- lapply(FR, FUN=PBR.sim.FR, tau=0, CV=0.2)
Res.FR.tau0.CV08 <- lapply(FR, FUN=PBR.sim.FR, tau=0, CV=0.8)
Res.FR.tau2.CV02 <- lapply(FR, FUN=PBR.sim.FR, tau=0.02, CV=0.2)
Res.FR.tau2.CV08 <- lapply(FR, FUN=PBR.sim.FR, tau=0.02, CV=0.8)
par(mfrow=c(2,2), mar=c(4,4,3,3))
Box.FinalD(Res.FR.tau0.CV02, List=FR, main="tau=0, CV=0.2")
Box.FinalD(Res.FR.tau0.CV08, List=FR, main="tau=0, CV=0.8")
Box.FinalD(Res.FR.tau2.CV02, List=FR, main="tau=0.02, CV=0.2")
Box.FinalD(Res.FR.tau2.CV08, List=FR, main="tau=0.02, CV=0.8")